@@ -8,7 +8,7 @@
 
 #include <PowerDevilProfileSettings.h>
 #include <powerdevil_debug.h>
-#include <powerdevilbackendinterface.h>
+#include <powerdevilcore.h>
 
 #include <QDebug>
 #include <QTimer>
@@ -54,7 +54,7 @@ void DimDisplay::onIdleTimeout(std::chrono::milliseconds timeout)
         return;
     }
 
-    if (backend()->screenBrightness() == 0) {
+    if (core()->screenBrightnessController()->brightness() == 0) {
         // Some drivers report brightness == 0 when display is off because of DPMS
         //(especially Intel driver). Don't change brightness in this case, or
         // backlight won't switch on later.
@@ -63,8 +63,8 @@ void DimDisplay::onIdleTimeout(std::chrono::milliseconds timeout)
     }
     qCDebug(POWERDEVIL) << "DimDisplay: triggered on idle timeout, dimming";
 
-    m_oldScreenBrightness = backend()->screenBrightness();
-    m_oldKeyboardBrightness = backend()->keyboardBrightness();
+    m_oldScreenBrightness = core()->screenBrightnessController()->brightness();
+    m_oldKeyboardBrightness = core()->keyboardBrightnessController()->brightness();
 
     // Dim brightness to 30% of the original. 30% is chosen arbitrarily based on
     // assumption that e.g. 50% may be too bright for returning user to notice that
@@ -80,12 +80,12 @@ void DimDisplay::setBrightnessHelper(int screenBrightness, int keyboardBrightnes
 {
     // don't arbitrarily turn-off the display
     if (screenBrightness > 0) {
-        backend()->setScreenBrightness(screenBrightness);
+        core()->screenBrightnessController()->setBrightness(screenBrightness);
     }
 
     // don't manipulate keyboard brightness if it's already zero to prevent races with DPMS action
     if (m_oldKeyboardBrightness > 0) {
-        backend()->setKeyboardBrightness(keyboardBrightness);
+        core()->keyboardBrightnessController()->setBrightness(keyboardBrightness);
     }
 }
 
@@ -95,7 +95,7 @@ void DimDisplay::triggerImpl(const QVariantMap & /*args*/)
 
 bool DimDisplay::isSupported()
 {
-    return backend()->screenBrightnessAvailable();
+    return core()->screenBrightnessController()->isSupported();
 }
 
 bool DimDisplay::loadAction(const PowerDevil::ProfileSettings &profileSettings)
@@ -108,10 +108,10 @@ bool DimDisplay::loadAction(const PowerDevil::ProfileSettings &profileSettings)
         if (m_dimmed) {
             if (!profileSettings.useProfileSpecificDisplayBrightness() && m_oldScreenBrightness > 0) {
                 qCDebug(POWERDEVIL) << "DimDisplay: restoring brightness on reload";
-                backend()->setScreenBrightness(m_oldScreenBrightness);
+                core()->screenBrightnessController()->setBrightness(m_oldScreenBrightness);
             }
             if (!profileSettings.useProfileSpecificKeyboardBrightness() && m_oldKeyboardBrightness > 0) {
-                backend()->setKeyboardBrightness(m_oldKeyboardBrightness);
+                core()->keyboardBrightnessController()->setBrightness(m_oldKeyboardBrightness);
             }
             m_dimmed = false;
         }
