@@ -1,34 +1,21 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *   Copyright (C) 2012 Lukáš Tinkl <ltinkl@redhat.com>                    *
- *   Copyright (C) 2016 Kai Uwe Broulik <kde@privat.broulik.de>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *   SPDX-FileCopyrightText: 2012 Lukáš Tinkl <ltinkl@redhat.com>
+ *   SPDX-FileCopyrightText: 2016 Kai Uwe Broulik <kde@privat.broulik.de>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include <QCoreApplication>
-#include <QDBusObjectPath>
 #include <QDBusArgument>
-#include <QMetaType>
-#include <QDBusMetaType>
 #include <QDBusConnection>
-#include <QDBusInterface>
-#include <QDBusPendingReply>
 #include <QDBusConnectionInterface>
+#include <QDBusInterface>
+#include <QDBusMetaType>
+#include <QDBusObjectPath>
+#include <QDBusPendingReply>
 #include <QDBusServiceWatcher>
+#include <QMetaType>
 #include <QTimer>
 
 #include <KIdleTime>
@@ -36,13 +23,12 @@
 #include <algorithm>
 #include <unistd.h>
 
-#include "powerdevilpolicyagent.h"
 #include "powerdevil_debug.h"
+#include "powerdevilpolicyagent.h"
 
 #include "screenlocker_interface.h"
 
-struct NamedDBusObjectPath
-{
+struct NamedDBusObjectPath {
     QString name;
     QDBusObjectPath path;
 };
@@ -89,14 +75,17 @@ Q_DECLARE_METATYPE(QList<InhibitionInfo>)
 
 namespace PowerDevil
 {
-
 static const QString SCREEN_LOCKER_SERVICE_NAME = QStringLiteral("org.freedesktop.ScreenSaver");
 
 class PolicyAgentHelper
 {
 public:
-    PolicyAgentHelper() : q(nullptr) { }
-    ~PolicyAgentHelper() {
+    PolicyAgentHelper()
+        : q(nullptr)
+    {
+    }
+    ~PolicyAgentHelper()
+    {
         delete q;
     }
     PolicyAgent *q;
@@ -113,7 +102,7 @@ PolicyAgent *PolicyAgent::instance()
     return s_globalPolicyAgent->q;
 }
 
-PolicyAgent::PolicyAgent(QObject* parent)
+PolicyAgent::PolicyAgent(QObject *parent)
     : QObject(parent)
     , m_screenLockerWatcher(new QDBusServiceWatcher(this))
     , m_sdAvailable(false)
@@ -141,14 +130,11 @@ void PolicyAgent::init()
 
     // Watch over the systemd service
     m_sdWatcher.data()->setConnection(QDBusConnection::systemBus());
-    m_sdWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration |
-                                     QDBusServiceWatcher::WatchForRegistration);
+    m_sdWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration);
     m_sdWatcher.data()->addWatchedService(SYSTEMD_LOGIN1_SERVICE);
 
-    connect(m_sdWatcher.data(), &QDBusServiceWatcher::serviceRegistered,
-            this, &PolicyAgent::onSessionHandlerRegistered);
-    connect(m_sdWatcher.data(), &QDBusServiceWatcher::serviceUnregistered,
-            this, &PolicyAgent::onSessionHandlerUnregistered);
+    connect(m_sdWatcher.data(), &QDBusServiceWatcher::serviceRegistered, this, &PolicyAgent::onSessionHandlerRegistered);
+    connect(m_sdWatcher.data(), &QDBusServiceWatcher::serviceUnregistered, this, &PolicyAgent::onSessionHandlerUnregistered);
     // If it's up and running already, let's cache it
     if (QDBusConnection::systemBus().interface()->isServiceRegistered(SYSTEMD_LOGIN1_SERVICE)) {
         onSessionHandlerRegistered(SYSTEMD_LOGIN1_SERVICE);
@@ -156,14 +142,11 @@ void PolicyAgent::init()
 
     // Watch over the ConsoleKit service
     m_ckWatcher.data()->setConnection(QDBusConnection::sessionBus());
-    m_ckWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration |
-                                     QDBusServiceWatcher::WatchForRegistration);
+    m_ckWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration | QDBusServiceWatcher::WatchForRegistration);
     m_ckWatcher.data()->addWatchedService(CONSOLEKIT_SERVICE);
 
-    connect(m_ckWatcher.data(), &QDBusServiceWatcher::serviceRegistered,
-            this, &PolicyAgent::onSessionHandlerRegistered);
-    connect(m_ckWatcher.data(), &QDBusServiceWatcher::serviceUnregistered,
-            this, &PolicyAgent::onSessionHandlerUnregistered);
+    connect(m_ckWatcher.data(), &QDBusServiceWatcher::serviceRegistered, this, &PolicyAgent::onSessionHandlerRegistered);
+    connect(m_ckWatcher.data(), &QDBusServiceWatcher::serviceUnregistered, this, &PolicyAgent::onSessionHandlerUnregistered);
     // If it's up and running already, let's cache it
     if (QDBusConnection::systemBus().interface()->isServiceRegistered(CONSOLEKIT_SERVICE)) {
         onSessionHandlerRegistered(CONSOLEKIT_SERVICE);
@@ -173,8 +156,7 @@ void PolicyAgent::init()
     m_busWatcher.data()->setConnection(QDBusConnection::sessionBus());
     m_busWatcher.data()->setWatchMode(QDBusServiceWatcher::WatchForUnregistration);
 
-    connect(m_busWatcher.data(), &QDBusServiceWatcher::serviceUnregistered,
-            this, &PolicyAgent::onServiceUnregistered);
+    connect(m_busWatcher.data(), &QDBusServiceWatcher::serviceUnregistered, this, &PolicyAgent::onServiceUnregistered);
 
     // Setup the screen locker watcher and check whether the screen is currently locked
     connect(m_screenLockerWatcher, &QDBusServiceWatcher::serviceOwnerChanged, this, &PolicyAgent::onScreenLockerOwnerChanged);
@@ -182,12 +164,10 @@ void PolicyAgent::init()
     m_screenLockerWatcher->addWatchedService(SCREEN_LOCKER_SERVICE_NAME);
 
     // async variant of QDBusConnectionInterface::serviceOwner ...
-    auto msg = QDBusMessage::createMethodCall(
-        QStringLiteral("org.freedesktop.DBus"),
-        QStringLiteral("/"),
-        QStringLiteral("org.freedesktop.DBus"),
-        QStringLiteral("GetNameOwner")
-    );
+    auto msg = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.DBus"),
+                                              QStringLiteral("/"),
+                                              QStringLiteral("org.freedesktop.DBus"),
+                                              QStringLiteral("GetNameOwner"));
     msg.setArguments({SCREEN_LOCKER_SERVICE_NAME});
 
     auto *watcher = new QDBusPendingCallWatcher(QDBusConnection::sessionBus().asyncCall(msg), this);
@@ -202,8 +182,7 @@ void PolicyAgent::init()
 
 QString PolicyAgent::getNamedPathProperty(const QString &path, const QString &iface, const QString &prop) const
 {
-    QDBusMessage message = QDBusMessage::createMethodCall(SYSTEMD_LOGIN1_SERVICE, path,
-                                                          QLatin1String("org.freedesktop.DBus.Properties"), QLatin1String("Get"));
+    QDBusMessage message = QDBusMessage::createMethodCall(SYSTEMD_LOGIN1_SERVICE, path, QLatin1String("org.freedesktop.DBus.Properties"), QLatin1String("Get"));
     message << iface << prop;
     QDBusMessage reply = QDBusConnection::systemBus().call(message);
 
@@ -217,7 +196,7 @@ QString PolicyAgent::getNamedPathProperty(const QString &path, const QString &if
     return QString();
 }
 
-void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
+void PolicyAgent::onSessionHandlerRegistered(const QString &serviceName)
 {
     if (serviceName == SYSTEMD_LOGIN1_SERVICE) {
         m_sdAvailable = true;
@@ -248,8 +227,7 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
         QString sessionPath = session.value().path();
         qCDebug(POWERDEVIL) << "Session path:" << sessionPath;
 
-        m_sdSessionInterface = new QDBusInterface(SYSTEMD_LOGIN1_SERVICE, sessionPath,
-                                                  SYSTEMD_LOGIN1_SESSION_IFACE, QDBusConnection::systemBus(), this);
+        m_sdSessionInterface = new QDBusInterface(SYSTEMD_LOGIN1_SERVICE, sessionPath, SYSTEMD_LOGIN1_SESSION_IFACE, QDBusConnection::systemBus(), this);
         if (!m_sdSessionInterface.data()->isValid()) {
             // As above
             qCDebug(POWERDEVIL) << "Can't contact session iface";
@@ -268,8 +246,7 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
         }
 
         // get the current seat
-        m_sdSeatInterface = new QDBusInterface(SYSTEMD_LOGIN1_SERVICE, seatPath,
-                                               SYSTEMD_LOGIN1_SEAT_IFACE, QDBusConnection::systemBus(), this);
+        m_sdSeatInterface = new QDBusInterface(SYSTEMD_LOGIN1_SERVICE, seatPath, SYSTEMD_LOGIN1_SEAT_IFACE, QDBusConnection::systemBus(), this);
 
         if (!m_sdSeatInterface.data()->isValid()) {
             // As above
@@ -283,16 +260,24 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
         m_activeSessionPath = getNamedPathProperty(seatPath, SYSTEMD_LOGIN1_SEAT_IFACE, "ActiveSession");
 
         qCDebug(POWERDEVIL) << "ACTIVE SESSION PATH:" << m_activeSessionPath;
-        QDBusConnection::systemBus().connect(SYSTEMD_LOGIN1_SERVICE, seatPath, "org.freedesktop.DBus.Properties", "PropertiesChanged", this,
-                                             SLOT(onActiveSessionChanged(QString,QVariantMap,QStringList)));
+        QDBusConnection::systemBus().connect(SYSTEMD_LOGIN1_SERVICE,
+                                             seatPath,
+                                             "org.freedesktop.DBus.Properties",
+                                             "PropertiesChanged",
+                                             this,
+                                             SLOT(onActiveSessionChanged(QString, QVariantMap, QStringList)));
 
         onActiveSessionChanged(m_activeSessionPath);
 
         // block logind from handling time-based inhibitions
         setupSystemdInhibition();
         // and then track logind's ihibitions, too
-        QDBusConnection::systemBus().connect(SYSTEMD_LOGIN1_SERVICE, SYSTEMD_LOGIN1_PATH, "org.freedesktop.DBus.Properties", "PropertiesChanged", this,
-                                             SLOT(onManagerPropertyChanged(QString,QVariantMap,QStringList)));
+        QDBusConnection::systemBus().connect(SYSTEMD_LOGIN1_SERVICE,
+                                             SYSTEMD_LOGIN1_PATH,
+                                             "org.freedesktop.DBus.Properties",
+                                             "PropertiesChanged",
+                                             this,
+                                             SLOT(onManagerPropertyChanged(QString, QVariantMap, QStringList)));
         checkLogindInhibitions();
 
         qCDebug(POWERDEVIL) << "systemd support initialized";
@@ -318,8 +303,8 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
             return;
         }
 
-        m_ckSessionInterface = new QDBusInterface(CONSOLEKIT_SERVICE, sessionPath.value().path(),
-                                                  "org.freedesktop.ConsoleKit.Session", QDBusConnection::systemBus());
+        m_ckSessionInterface =
+            new QDBusInterface(CONSOLEKIT_SERVICE, sessionPath.value().path(), "org.freedesktop.ConsoleKit.Session", QDBusConnection::systemBus());
 
         if (!m_ckSessionInterface.data()->isValid()) {
             // As above
@@ -329,7 +314,7 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
         }
 
         // Now let's obtain the seat
-        QDBusPendingReply< QDBusObjectPath > seatPath = m_ckSessionInterface.data()->asyncCall(QStringLiteral("GetSeatId"));
+        QDBusPendingReply<QDBusObjectPath> seatPath = m_ckSessionInterface.data()->asyncCall(QStringLiteral("GetSeatId"));
         seatPath.waitForFinished();
 
         if (!seatPath.isValid() || seatPath.value().path().isEmpty()) {
@@ -338,18 +323,20 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
             return;
         }
 
-        if (!QDBusConnection::systemBus().connect(CONSOLEKIT_SERVICE, seatPath.value().path(),
-                                                  "org.freedesktop.ConsoleKit.Seat", "ActiveSessionChanged",
-                                                  this, SLOT(onActiveSessionChanged(QString)))) {
+        if (!QDBusConnection::systemBus().connect(CONSOLEKIT_SERVICE,
+                                                  seatPath.value().path(),
+                                                  "org.freedesktop.ConsoleKit.Seat",
+                                                  "ActiveSessionChanged",
+                                                  this,
+                                                  SLOT(onActiveSessionChanged(QString)))) {
             qCDebug(POWERDEVIL) << "Unable to connect to ActiveSessionChanged";
             m_ckAvailable = false;
             return;
         }
 
         // Force triggering of active session changed
-        QDBusMessage call = QDBusMessage::createMethodCall(CONSOLEKIT_SERVICE, seatPath.value().path(),
-                                                           "org.freedesktop.ConsoleKit.Seat", "GetActiveSession");
-        QDBusPendingReply< QDBusObjectPath > activeSession = QDBusConnection::systemBus().asyncCall(call);
+        QDBusMessage call = QDBusMessage::createMethodCall(CONSOLEKIT_SERVICE, seatPath.value().path(), "org.freedesktop.ConsoleKit.Seat", "GetActiveSession");
+        QDBusPendingReply<QDBusObjectPath> activeSession = QDBusConnection::systemBus().asyncCall(call);
         activeSession.waitForFinished();
 
         onActiveSessionChanged(activeSession.value().path());
@@ -357,24 +344,22 @@ void PolicyAgent::onSessionHandlerRegistered(const QString & serviceName)
         setupSystemdInhibition();
 
         qCDebug(POWERDEVIL) << "ConsoleKit support initialized";
-    }
-    else
+    } else
         qCWarning(POWERDEVIL) << "Unhandled service registered:" << serviceName;
 }
 
-void PolicyAgent::onSessionHandlerUnregistered(const QString & serviceName)
+void PolicyAgent::onSessionHandlerUnregistered(const QString &serviceName)
 {
     if (serviceName == QLatin1String(SYSTEMD_LOGIN1_SERVICE)) {
         m_sdAvailable = false;
         delete m_sdSessionInterface.data();
-    }
-    else if (serviceName == QLatin1String(CONSOLEKIT_SERVICE)) {
+    } else if (serviceName == QLatin1String(CONSOLEKIT_SERVICE)) {
         m_ckAvailable = false;
         delete m_ckSessionInterface.data();
     }
 }
 
-void PolicyAgent::onActiveSessionChanged(const QString & ifaceName, const QVariantMap & changedProps, const QStringList & invalidatedProps)
+void PolicyAgent::onActiveSessionChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps)
 {
     const QString key = QLatin1String("ActiveSession");
 
@@ -385,13 +370,13 @@ void PolicyAgent::onActiveSessionChanged(const QString & ifaceName, const QVaria
     }
 }
 
-void PolicyAgent::onActiveSessionChanged(const QString& activeSession)
+void PolicyAgent::onActiveSessionChanged(const QString &activeSession)
 {
     if (activeSession.isEmpty() || activeSession == QLatin1String("/")) {
         qCDebug(POWERDEVIL) << "Switched to inactive session - leaving unchanged";
         return;
-    } else if ((!m_sdSessionInterface.isNull() && activeSession == m_sdSessionInterface.data()->path()) ||
-               (!m_ckSessionInterface.isNull() && activeSession == m_ckSessionInterface.data()->path())) {
+    } else if ((!m_sdSessionInterface.isNull() && activeSession == m_sdSessionInterface.data()->path())
+               || (!m_ckSessionInterface.isNull() && activeSession == m_ckSessionInterface.data()->path())) {
         qCDebug(POWERDEVIL) << "Current session is now active";
         if (!m_wasLastActiveSession) {
             m_wasLastActiveSession = true;
@@ -449,15 +434,13 @@ void PolicyAgent::checkLogindInhibitions()
                 continue;
             }
 
-            const bool known = std::find(m_logindInhibitions.constBegin(),
-                                         m_logindInhibitions.constEnd(),
-                                         activeInhibition) != m_logindInhibitions.constEnd();
+            const bool known = std::find(m_logindInhibitions.constBegin(), m_logindInhibitions.constEnd(), activeInhibition) != m_logindInhibitions.constEnd();
             if (known) {
                 continue;
             }
 
-            qCDebug(POWERDEVIL) << "Adding logind inhibition:" << activeInhibition.what << activeInhibition.who << activeInhibition.why
-                                << "from" << activeInhibition.pid << "of user" << activeInhibition.uid;
+            qCDebug(POWERDEVIL) << "Adding logind inhibition:" << activeInhibition.what << activeInhibition.who << activeInhibition.why << "from"
+                                << activeInhibition.pid << "of user" << activeInhibition.uid;
             const uint cookie = AddInhibition(policies, activeInhibition.who, activeInhibition.why);
             m_logindInhibitions.insert(cookie, activeInhibition);
         }
@@ -484,7 +467,7 @@ void PolicyAgent::onManagerPropertyChanged(const QString &ifaceName, const QVari
     }
 }
 
-void PolicyAgent::onServiceUnregistered(const QString& serviceName)
+void PolicyAgent::onServiceUnregistered(const QString &serviceName)
 {
     // Ouch - the application quit or crashed without releasing its inhibitions. Let's fix that.
 
@@ -501,9 +484,6 @@ PolicyAgent::RequiredPolicies PolicyAgent::unavailablePolicies()
 {
     RequiredPolicies retpolicies = None;
 
-    if (!m_typesToCookie[ChangeProfile].isEmpty()) {
-        retpolicies |= ChangeProfile;
-    }
     // when screen locker is active it makes no sense to keep the screen on
     if (!m_screenLockerActive && !m_typesToCookie[ChangeScreenSettings].isEmpty()) {
         retpolicies |= ChangeScreenSettings;
@@ -537,7 +517,7 @@ PolicyAgent::RequiredPolicies PolicyAgent::requirePolicyCheck(PolicyAgent::Requi
         // No way to determine if we are on the current session, simply suppose we are
         qCDebug(POWERDEVIL) << "Can't contact ck";
     } else if (!m_ckSessionInterface.isNull()) {
-        QDBusPendingReply< bool > rp = m_ckSessionInterface.data()->asyncCall(QStringLiteral("IsActive"));
+        QDBusPendingReply<bool> rp = m_ckSessionInterface.data()->asyncCall(QStringLiteral("IsActive"));
         rp.waitForFinished();
 
         if (!(rp.isValid() && rp.value()) && !m_wasLastActiveSession) {
@@ -548,11 +528,6 @@ PolicyAgent::RequiredPolicies PolicyAgent::requirePolicyCheck(PolicyAgent::Requi
     // Ok, let's go then
     RequiredPolicies retpolicies = None;
 
-    if (policies & ChangeProfile) {
-        if (!m_typesToCookie[ChangeProfile].isEmpty()) {
-            retpolicies |= ChangeProfile;
-        }
-    }
     if (policies & ChangeScreenSettings) {
         if (!m_typesToCookie[ChangeScreenSettings].isEmpty()) {
             retpolicies |= ChangeScreenSettings;
@@ -567,16 +542,6 @@ PolicyAgent::RequiredPolicies PolicyAgent::requirePolicyCheck(PolicyAgent::Requi
     return retpolicies;
 }
 
-void PolicyAgent::startSessionInterruption()
-{
-    m_sessionIsBeingInterrupted = true;
-}
-
-void PolicyAgent::finishSessionInterruption()
-{
-    m_sessionIsBeingInterrupted = false;
-}
-
 void PolicyAgent::onScreenLockerOwnerChanged(const QString &serviceName, const QString &oldOwner, const QString &newOwner)
 {
     Q_UNUSED(oldOwner);
@@ -620,8 +585,7 @@ void PolicyAgent::onScreenLockerActiveChanged(bool active)
     }
 }
 
-uint PolicyAgent::addInhibitionWithExplicitDBusService(uint types, const QString &appName,
-                                                       const QString &reason, const QString &service)
+uint PolicyAgent::addInhibitionWithExplicitDBusService(uint types, const QString &appName, const QString &reason, const QString &service)
 {
     ++m_lastCookie;
 
@@ -634,15 +598,13 @@ uint PolicyAgent::addInhibitionWithExplicitDBusService(uint types, const QString
 
     m_pendingInhibitions.append(cookie);
 
-    qCDebug(POWERDEVIL) << "Scheduling inhibition from" << service << appName << "with cookie"
-                        << cookie << "and reason" << reason;
+    qCDebug(POWERDEVIL) << "Scheduling inhibition from" << service << appName << "with cookie" << cookie << "and reason" << reason;
 
     // wait 5s before actually enforcing the inhibition
     // there might be short interruptions (such as receiving a message) where an app might automatically
     // post an inhibition but we don't want the system to constantly wakeup because of this
-    QTimer::singleShot(5000, this, [=] {
-        qCDebug(POWERDEVIL) << "Enforcing inhibition from" << service << appName << "with cookie"
-                            << cookie << "and reason" << reason;
+    QTimer::singleShot(5000, this, [this, cookie, service, reason, appName, types] {
+        qCDebug(POWERDEVIL) << "Enforcing inhibition from" << service << appName << "with cookie" << cookie << "and reason" << reason;
 
         if (!m_pendingInhibitions.contains(cookie)) {
             qCDebug(POWERDEVIL) << "By the time we wanted to enforce the inhibition it was already gone; discarding it";
@@ -651,9 +613,9 @@ uint PolicyAgent::addInhibitionWithExplicitDBusService(uint types, const QString
 
         m_cookieToAppName.insert(cookie, qMakePair(appName, reason));
 
-        addInhibitionTypeHelper(cookie, static_cast< PolicyAgent::RequiredPolicies >(types));
+        addInhibitionTypeHelper(cookie, static_cast<PolicyAgent::RequiredPolicies>(types));
 
-        Q_EMIT InhibitionsChanged({ {qMakePair(appName, reason)} }, {});
+        Q_EMIT InhibitionsChanged({{qMakePair(appName, reason)}}, {});
 
         m_pendingInhibitions.removeOne(cookie);
     });
@@ -674,14 +636,6 @@ void PolicyAgent::addInhibitionTypeHelper(uint cookie, PolicyAgent::RequiredPoli
 {
     // Look through all of the inhibition types
     bool notify = false;
-    if (types & ChangeProfile) {
-        // Check if we have to notify
-        if (m_typesToCookie[ChangeProfile].isEmpty()) {
-            qCDebug(POWERDEVIL) << "Added change profile";
-            notify = true;
-        }
-        m_typesToCookie[ChangeProfile].append(cookie);
-    }
     if (types & ChangeScreenSettings) {
         // Check if we have to notify
         qCDebug(POWERDEVIL) << "Added change screen settings";
@@ -689,7 +643,7 @@ void PolicyAgent::addInhibitionTypeHelper(uint cookie, PolicyAgent::RequiredPoli
             notify = true;
         }
         m_typesToCookie[ChangeScreenSettings].append(cookie);
-        types |= InterruptSession;  // implied by ChangeScreenSettings
+        types |= InterruptSession; // implied by ChangeScreenSettings
     }
     if (types & InterruptSession) {
         // Check if we have to notify
@@ -721,18 +675,11 @@ void PolicyAgent::ReleaseInhibition(uint cookie)
         return;
     }
 
-    Q_EMIT InhibitionsChanged(QList<InhibitionInfo>(), { {m_cookieToAppName.value(cookie).first} });
+    Q_EMIT InhibitionsChanged(QList<InhibitionInfo>(), {{m_cookieToAppName.value(cookie).first}});
     m_cookieToAppName.remove(cookie);
 
     // Look through all of the inhibition types
     bool notify = false;
-    if (m_typesToCookie[ChangeProfile].contains(cookie)) {
-        m_typesToCookie[ChangeProfile].removeOne(cookie);
-        // Check if we have to notify
-        if (m_typesToCookie[ChangeProfile].isEmpty()) {
-            notify = true;
-        }
-    }
     if (m_typesToCookie[ChangeScreenSettings].contains(cookie)) {
         m_typesToCookie[ChangeScreenSettings].removeOne(cookie);
         // Check if we have to notify
@@ -766,7 +713,7 @@ bool PolicyAgent::HasInhibition(/*PolicyAgent::RequiredPolicies*/ uint types)
 
 void PolicyAgent::releaseAllInhibitions()
 {
-    const QList< uint > allCookies = m_cookieToAppName.keys();
+    const QList<uint> allCookies = m_cookieToAppName.keys();
     for (uint cookie : allCookies) {
         ReleaseInhibition(cookie);
     }
@@ -783,7 +730,8 @@ void PolicyAgent::setupSystemdInhibition()
     // inhibit systemd/ConsoleKit2 handling of power/sleep/lid buttons
     // https://www.freedesktop.org/wiki/Software/systemd/inhibit
     // https://consolekit2.github.io/ConsoleKit2/#Manager.Inhibit
-    qCDebug(POWERDEVIL) << "fd passing available:" << bool(m_managerIface.data()->connection().connectionCapabilities() & QDBusConnection::UnixFileDescriptorPassing);
+    qCDebug(POWERDEVIL) << "fd passing available:"
+                        << bool(m_managerIface.data()->connection().connectionCapabilities() & QDBusConnection::UnixFileDescriptorPassing);
 
     QVariantList args;
     args << QStringLiteral("handle-power-key:handle-suspend-key:handle-hibernate-key:handle-lid-switch"); // what
@@ -795,9 +743,10 @@ void PolicyAgent::setupSystemdInhibition()
     if (desc.isValid()) {
         m_systemdInhibitFd = desc.value();
         qCDebug(POWERDEVIL) << "systemd powersave events handling inhibited, descriptor:" << m_systemdInhibitFd.fileDescriptor();
-    }
-    else
+    } else
         qCWarning(POWERDEVIL) << "failed to inhibit systemd powersave handling";
 }
 
 }
+
+#include "moc_powerdevilpolicyagent.cpp"
